{% load thumbnail %}
<blockquote>
    {{ instance.content|safe }}
    <small>
        {% if instance.link %}<a href="{{ instance.link }}">{% endif %}
        {% if instance.image %}<img src="{% thumbnail instance.image 40x40 crop %}">{% endif %}
        {{ instance.name }}
        {% if instance.link %}</a>{% endif %}
    </small>
</blockquote>
