<a class="btn {%if instance.subtitle %}btn-biline{% endif %}" href="{{ instance.get_link }}">{% if instance.icon %}<i class="fa fa-{{ instance.icon }}"></i> {% endif %}{{ instance.title }}{% if instance.subtitle %}<span class="biline">{{ instance.subtitle }}</span>{% endif %}</a>
