<div class="item {% if parentloop.first %}active{% endif %}">
    {% with link=instance.get_link %}
        {% if link %}<a href="{{ instance.get_link }}">{% endif %}
        <img src="{{ instance.image.url }}" alt="{{ instance.get_title }}">
        <div class="carousel-caption">{{ instance.get_description }}</div>
        {% if link %}</a>{% endif %}
    {% endwith %}
</div>
